==> opentoonz-dmo_1.6.0.orig.tar.xz: opentoonz-1.6.0/toonz/sources/translations/korean/tnzcore.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
<context>
    <name>BmpWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation>8비트</translation>
    </message>
</context>
<context>
    <name>JpgWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Smoothing</source>
        <translation>평활화</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>colors</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Skipping frame.</source>
        <translation>프레임 건너뛰기</translation>
    </message>
    <message>
        <source>Malformed frame name</source>
        <translation type="vanished">잘못된 형식의 프레임</translation>
    </message>
    <message>
        <source>Unidentified Action</source>
        <translation>식별되지 않은 작업</translation>
    </message>
</context>
<context>
    <name>TCenterLineStrokeStyle</name>
    <message>
        <source>Constant</source>
        <translation>일정한</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
</context>
<context>
    <name>TRasterImagePatternStrokeStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
</context>
<context>
    <name>TVectorImagePatternStrokeStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
</context>
<context>
    <name>Tiio::BmpWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation type="vanished">픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation type="vanished">24비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation type="vanished">8비트</translation>
    </message>
</context>
<context>
    <name>Tiio::JpgWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation type="vanished">품질</translation>
    </message>
    <message>
        <source>Smoothing</source>
        <translation type="vanished">평활화</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.7.1.1.orig.tar.xz: opentoonz-1.7.1.1/toonz/sources/translations/korean/tnzcore.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
<context>
    <name>BmpWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation>8비트</translation>
    </message>
</context>
<context>
    <name>JpgWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Smoothing</source>
        <translation>평활화</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>colors</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Skipping frame.</source>
        <translation>프레임 건너뛰기.</translation>
    </message>
    <message>
        <source>Malformed frame name</source>
        <translation>잘못된 형식의 프레임</translation>
    </message>
    <message>
        <source>Unidentified Action</source>
        <translation>식별되지 않은 작업</translation>
    </message>
</context>
<context>
    <name>TCenterLineStrokeStyle</name>
    <message>
        <source>Constant</source>
        <translation>일정한</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
</context>
<context>
    <name>TRasterImagePatternStrokeStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
</context>
<context>
    <name>TVectorImagePatternStrokeStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>회전</translation>
    </message>
</context>
<context>
    <name>Tiio::BmpWriterProperties</name>
    <message>
        <source>Bits Per Pixel</source>
        <translation>픽셀당 비트 수</translation>
    </message>
    <message>
        <source>24 bits</source>
        <translation>24비트</translation>
    </message>
    <message>
        <source>8 bits (Greyscale)</source>
        <translation>8비트</translation>
    </message>
</context>
<context>
    <name>Tiio::JpgWriterProperties</name>
    <message>
        <source>Quality</source>
        <translation>품질</translation>
    </message>
    <message>
        <source>Smoothing</source>
        <translation>평활화</translation>
    </message>
</context>
</TS>
